@@ -52,7 +52,6 @@
 #
 # * Ruby[http://www.ruby-lang.org] 1.8.x
 # * Ruby/LDAP[http://ruby-ldap.sourceforge.net]
-# * Log4r[http://log4r.sourceforge.net]
 # * (Optional) Ruby/LDAP+GSSAPI[http://caliban.org/files/redhat/RPMS/i386/ruby-ldap-0.8.2-4.i386.rpm]
 # * An LDAP server compatible with Ruby/LDAP: OpenLDAP[http://www.openldap.org], etc
 #   - Your LDAP server must allow root_dse queries to allow for schema queries
@@ -61,7 +60,7 @@
 # === Installation
 #
 # Assuming all the requirements are installed, you can install by grabbing the latest tgz file from
-# the download site[http://projects.dataspill.org/libraries/ruby/activeldap/download.html].
+# the download site[http://rubyforge.org/frs/?group_id=381].
 #
 # The following steps will get the Ruby/ActiveLdap installed in no time!
 #
@@ -75,9 +74,7 @@
 #
 # Now run:
 #
-#   $ ruby setup.rb config
-#   $ ruby setup.rb setup
-#   $ (as root) ruby setup.rb install
+#   $ (as root) rake install
 #
 # Now as a quick test, you can run:
 #
@@ -179,7 +176,7 @@
 #   class Group < ActiveLdap::Base
 #     ldap_mapping :dn_attribute => 'cn',
 #                  :prefix => 'ou=Groups', :classes => ['top', 'posixGroup']
-#                  :scope => LDAP::LDAP_SCOPE_ONELEVEL
+#                  :scope => :one
 #   end
 #
 # As you can see, this method is used for defining how this class maps in to LDAP.  Let's say that
@@ -436,7 +433,7 @@
 #     :host => 'ldap.dataspill.org',
 #     :port => 389,
 #     :base => 'dc=dataspill,dc=org',
-#     :logger => log4r_obj,
+#     :logger => logger_object,
 #     :bind_dn => "uid=drewry,ou=People,dc=dataspill,dc=org",
 #     :password_block => Proc.new { 'password12345' },
 #     :allow_anonymous => false,
@@ -462,7 +459,7 @@
 #   subclasses.
 # * :bind_dn specifies what your server expects when attempting to bind with
 #   credentials.
-# * :logger accepts a custom log4r object to integrate with any other logging
+# * :logger accepts a custom logger object to integrate with any other logging
 #   your application uses.
 # * :password_block, if defined, give the Proc block for acquiring the password
 # * :password, if defined, give the user's password as a String
@@ -475,7 +472,7 @@
 # * :method indicates whether to use :ssl, :tls, or :plain
 # * :retries - indicates the number of attempts to reconnect that will be undertaken when a stale connection occurs. -1 means infinite.
 # * :retry_wait - seconds to wait before retrying a connection
-# * :ldap_scope - dictates how to find objects. (Default: ONELEVEL)
+# * :scope - dictates how to find objects. (Default: :one)
 # * :timeout - time in seconds - defaults to disabled. This CAN interrupt search() requests. Be warned.
 # * :retry_on_timeout - whether to reconnect when timeouts occur. Defaults to true
 # See lib/configuration.rb for defaults for each option
@@ -907,18 +904,12 @@
 # package, and I'd like to see it prove helpful to more people than just myself.
 #
 
-if RUBY_PLATFORM.match('linux')
-  require 'active_ldap/timeout'
-else
-  require 'active_ldap/timeout_stub'
-end
-
 require_gem_if_need = Proc.new do |library_name, gem_name|
   begin
     require library_name
   rescue LoadError
     require 'rubygems'
-    require_gem gem_name
+    gem gem_name
     require library_name
   end
 end
@@ -929,28 +920,55 @@ if Dependencies.respond_to?(:load_paths)
   Dependencies.load_paths << File.expand_path(File.dirname(__FILE__))
 end
 
+module ActiveLdap
+  VERSION = "0.9.0"
+end
+
+if RUBY_PLATFORM.match('linux')
+  require 'active_ldap/timeout'
+else
+  require 'active_ldap/timeout_stub'
+end
+
+require_gem_if_need.call("active_record", "activerecord")
+begin
+  require_gem_if_need.call("gettext/active_record", "gettext")
+rescue LoadError
+end
+require 'active_ldap/get_text'
+
 require 'active_ldap/base'
+
 require 'active_ldap/associations'
+require 'active_ldap/attributes'
 require 'active_ldap/configuration'
 require 'active_ldap/connection'
-require 'active_ldap/attributes'
+require 'active_ldap/operations'
 require 'active_ldap/object_class'
+require 'active_ldap/human_readable'
+
+require 'active_ldap/acts/tree'
+
 require 'active_ldap/distinguished_name'
+require 'active_ldap/populate'
+require 'active_ldap/escape'
+require 'active_ldap/helper'
 
-require_gem_if_need.call("active_record/base", "activerecord")
 require 'active_ldap/validations'
 require 'active_ldap/callbacks'
 
-module ActiveLdap
-  VERSION = "0.8.2"
-end
 
 ActiveLdap::Base.class_eval do
+  include ActiveLdap::Associations
+  include ActiveLdap::Attributes
   include ActiveLdap::Configuration
   include ActiveLdap::Connection
-  include ActiveLdap::Attributes
+  include ActiveLdap::Operations
   include ActiveLdap::ObjectClass
-  include ActiveLdap::Associations
+  include ActiveLdap::HumanReadable
+
+  include ActiveLdap::Acts::Tree
+
   include ActiveLdap::Validations
   include ActiveLdap::Callbacks
 end
