@@ -27,12 +27,15 @@ module ActiveLdap
       end
 
       def find_target
-        key = @options[:many]
         values = @owner[@options[:foreign_key_name], true].compact
+        return [] if values.empty?
+
+        key = @options[:many]
         components = values.collect do |value|
           [key, value]
         end
-        foreign_class.find(:all, :filter => [:or, *components])
+        options = find_options(:filter => [:or, *components])
+        foreign_class.find(:all, options)
       end
     end
   end
