@@ -16,9 +16,10 @@ class TestBind < Test::Unit::TestCase
     assert(!ActiveLdap::Base.connected?)
     assert_nothing_raised do
       config = ActiveLdap::Base.configurations[LDAP_ENV].symbolize_keys
+      config = ActiveLdap::Base.prepare_configuration(config)
       config.delete(:bind_dn)
       config[:allow_anonymous] = true
-      ActiveLdap::Base.establish_connection(config)
+      connect(config)
     end
     assert(ActiveLdap::Base.connected?,
            "Checking is the connection was established.")
@@ -27,13 +28,14 @@ class TestBind < Test::Unit::TestCase
   def test_bind
     assert(!ActiveLdap::Base.connected?)
     config = ActiveLdap::Base.configurations[LDAP_ENV].symbolize_keys
+    config = ActiveLdap::Base.prepare_configuration(config)
     if config[:bind_dn].nil?
       puts "pass this test for no user configuration"
       return
     end
     assert_nothing_raised do
       config[:allow_anonymous] = false
-      ActiveLdap::Base.establish_connection(config)
+      connect(config)
     end
     assert(ActiveLdap::Base.connected?,
            "Checking is the connection was established.")
@@ -44,10 +46,17 @@ class TestBind < Test::Unit::TestCase
     assert(!ActiveLdap::Base.connected?)
     assert_raises(ActiveLdap::AuthenticationError) do
       config = ActiveLdap::Base.configurations[LDAP_ENV].symbolize_keys
+      config = ActiveLdap::Base.prepare_configuration(config)
       config.delete(:bind_dn)
       config[:allow_anonymous] = false
-      ActiveLdap::Base.establish_connection(config)
+      connect(config)
     end
     assert(!ActiveLdap::Base.connection.bound?)
   end
+
+  private
+  def connect(config)
+    ActiveLdap::Base.establish_connection(config)
+    ActiveLdap::Base.connection.connect
+  end
 end
